@@ -1,4 +1,4 @@
-from .apply_transformations_dataset import ApplyTransformationsDataset, ManipulateData
+from .manipulate_data import ManipulateData
 from .compute_similarities import *
 from .compute_similarities_summary_metrics import *
 from .create_dataset_versions import *
